@@ -7,11 +7,11 @@ Elive - Elluminate Live! (c) client library
 
 =head1 VERSION
 
-Version 0.64
+Version 0.65
 
 =cut
 
-our $VERSION = '0.64';
+our $VERSION = '0.65';
 
 use Class::Data::Inheritable;
 use base qw{Class::Data::Inheritable};
@@ -99,7 +99,8 @@ BEGIN {
 Connects to an Elluminate server instance. Dies if the connection could not
 be established. If, for example, the SOAP connection or user login failed.
 
-The login user must be an Elluminate I<Live!> system administrator account.
+The login user must either be an Elluminate I<Live!> system administrator
+account, or a user that has been granted access to the SDK (see README file).
 
 See also Elive::Connection.
 
@@ -388,17 +389,17 @@ Elluminate Services Errors:
 
 =over 4
 
-=item   "Unable to determine a command for the key : listXxxx"
+=item   "Unable to determine a command for the key : Xxxx"
 
-This may indicate that the particular command adaptor is is not available for
-your site instance.
+This may indicate that the particular command adaptor is is not available
+for your site instance. Please follow the instructions in the README file
+for detecting and repairing missing adapters.
 
-Check that your Elluminate I<Live!> server software version; This module
-has been tested against 9.0, 9.1 and 9.5.2
+=item   "User [<username>], not permitted to access the command {<command>]"
 
-If the problem persists, the command entry may be missing from your site
-configuration file. Please follow the instructions in the README file
-for instructions on detecting and repairing missing adapters.
+Please ensure that the user is a sytem administrator account and/or the
+user has been configured for SDK access. See also the instruction in the
+RRADME file.
 
 =back
 
@@ -502,7 +503,7 @@ see the README file.
 
 =head1 SEE ALSO
 
-Perl Modules:
+Perl Modules (included in the Elive distribution):
 
 =over 4
 
@@ -532,7 +533,7 @@ Perl Modules:
 
 =back
 
-Scripts:
+Scripts (included in the Elive distribution):
 
 =over 4
 
@@ -544,7 +545,7 @@ Scripts:
 
 =back
 
-Elluminate I<Live!> Documentation. This comes with your distribution
+Elluminate I<Live!> Documentation, installed with Elluminate.
 
 =over 4
 
@@ -609,8 +610,8 @@ such as users, meetings, preloads and meeting participants.
 =item Elive does not support hosted (SAS) systems
 
 The package currently supports only the installed server version of Elluminate
-Live which uses the ELM management layer. It does not yet support the hosted
-servers deployed with SAS (Session Administration System).
+Live which uses the ELM management layer. The current release does not support
+the hosted servers deployed with SAS (Session Administration System).
 
 =back
 
@@ -654,7 +655,7 @@ direction during the construction of this module.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009 David Warring, all rights reserved.
+Copyright 2009-2010 David Warring, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
